.. lim documentation master file.

lim
===

``lim`` is a command line interface (CLI) intended to access, manipulate,
and process computer and network security information.

The original motivation behind this utility was to facilitate prototyping
data analysis and data processing features for some commercial products and
services under development. Later, some of the functionality was used for
a client engagement involving creation of materials for developing security
operations analyst skills.

Then, in January 2020, a novel coronavirus took hold all around the world
and put our novel business in an induced coma, its founders isolated under
"stay at home" orders, with an uncertain future...

What better time to release this tool, demonstrate how it can be used,
and see where it leads? :)


Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   ctu
   packet-cafe
   testing
   contributing
   authors
   changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

